/*
 *      Copyright (C) 2000 Nikos Mavroyanopoulos
 *
 * This file is part of GNUTLS.
 *
 * GNUTLS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GNUTLS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

int gnutls_cipher_set_priority( gnutls_session session, gnutls_list);
int gnutls_kx_set_priority( gnutls_session session, gnutls_list); 
int gnutls_mac_set_priority( gnutls_session session, gnutls_list);
int gnutls_compression_set_priority( gnutls_session session, gnutls_list);
int gnutls_protocol_set_priority( gnutls_session session, gnutls_list);
int gnutls_certificate_type_set_priority( gnutls_session session, gnutls_list);
